@@ -6,11 +6,11 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 1.29_01
+Version 1.31_01
 
 =cut
 
-our $VERSION = '1.29_01';
+our $VERSION = '1.31_01';
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ traverse.
 
     $mech->back();
 
-If you want finer control over over your page fetching, you can use
+If you want finer control over your page fetching, you can use
 these methods. C<follow_link> and C<submit_form> are just high
 level wrappers around them.
 
@@ -177,7 +177,7 @@ calling C<< $mech->quiet(1) >>.  Default is off.
 
 =item * C<< stack_depth => $value >>
 
-Sets the depth of the page stack that keeps tracks of all the downloaded
+Sets the depth of the page stack that keeps track of all the downloaded
 pages. Default is 0 (infinite). If the stack is eating up your memory,
 then set it to 1.
 
@@ -198,7 +198,7 @@ sub new {
         onwarn      => \&WWW::Mechanize::_warn,
         onerror     => \&WWW::Mechanize::_die,
         quiet       => 0,
-        stack_depth => 867_5309,    # Arbitrarily humungous stack
+        stack_depth => 8675309,     # Arbitrarily humongous stack
         headers     => {},
     );
 
@@ -263,7 +263,23 @@ sets your User-Agent to
 
     Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)
 
-The list of valid aliases can be returned from C<known_agent_aliases()>.
+The list of valid aliases can be returned from C<known_agent_aliases()>.  The current list is:
+
+=over
+
+=item * Windows IE 6
+
+=item * Windows Mozilla
+
+=item * Mac Safari
+
+=item * Mac Mozilla
+
+=item * Linux Mozilla
+
+=item * Linux Konqueror
+
+=back
 
 =cut
 
@@ -336,7 +352,7 @@ sub get {
     return $self->SUPER::get( $uri->as_string, @_ );
 }
 
-=head2 $mech->put( $uri, 'content' => $content )
+=head2 $mech->put( $uri, content => $content )
 
 PUTs I<$content> to $uri.  Returns an L<HTTP::Response> object.
 I<$uri> can be a well-formed URI string, a L<URI> object, or a
@@ -537,7 +553,7 @@ sub content {
         my %parms = @_;
         if ( exists $parms{base_href} ) {
             my $arg = (delete $parms{base_href}) || $self->base;
-            $content=~s/<head>/<head>\n<base href="$arg">/;
+            $content=~s/<head>/<head>\n<base href="$arg">/i;
         }
         if ( my $arg = delete $parms{format} ) {
             if ($arg eq 'text') {
@@ -838,7 +854,7 @@ sub find_all_links {
     return $self->find_link( @_, n=>'all' );
 }
 
-=head2 find_all_inputs( ... criteria ... )
+=head2 $mech->find_all_inputs( ... criteria ... )
 
 find_all_inputs() returns an array of all the input controls in the
 current form whose properties match all of the regexes passed in.
@@ -935,7 +951,7 @@ Finds an image in the current page. It returns a
 L<WWW::Mechanize::Image> object which describes the image.  If it fails
 to find an image it returns undef.
 
-You can select which link to find by passing in one or more of these
+You can select which image to find by passing in one or more of these
 key/value pairs:
 
 =over 4
@@ -1089,7 +1105,7 @@ calls to C<L<field()>> and C<L<click()>>.  Also returns the form that was
 selected.
 
 If it is found, the form is returned as an L<HTML::Form> object and set internally
-for later used with Mech's form methods such as C<L<field()>> and C<L<click()>>.
+for later use with Mech's form methods such as C<L<field()>> and C<L<click()>>.
 
 Emits a warning and returns undef if no form is found.
 
@@ -1118,7 +1134,7 @@ with that name, then the first one is used, and a warning is
 generated.
 
 If it is found, the form is returned as an L<HTML::Form> object and set internally
-for later used with Mech's form methods such as C<L<field()>> and C<L<click()>>.
+for later use with Mech's form methods such as C<L<field()>> and C<L<click()>>.
 
 Returns undef if no form is found.
 
@@ -2396,9 +2412,9 @@ __END__
 
 =head1 WWW::MECHANIZE'S SUBVERSION REPOSITORY
 
-Mech is hosted by the kind generosity of Ask and Robert,
-maintainers of perl.org.  The Subversion repository is at
-L<http://svn.perl.org/modules/www-mechanize>.
+Mech and Test::WWW::Mechanize are both hosted at Google Code:
+http://code.google.com/p/www-mechanize/.  The Subversion repository
+is at http://www-mechanize.googlecode.com/svn/wm/.
 
 =head1 OTHER DOCUMENTATION
 
@@ -2547,8 +2563,8 @@ Just like Mech, but using Microsoft Internet Explorer to do the work.
 
 Please report any requests, suggestions or (gasp!) bugs via the
 excellent RT bug-tracking system at http://rt.cpan.org/, or email to
-bug-WWW-Mechanize@rt.cpan.org.  This makes it much easier for me to
-track things.
+C<bug-WWW-Mechanize at rt.cpan.org>.  This makes it much easier for
+me to track things.
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Mechanize> is the RT queue
 for Mechanize.  Please check to see if your bug has already been reported.
@@ -2560,7 +2576,8 @@ to read the FAQ if you have support requests.
 
 Thanks to the numerous people who have helped out on WWW::Mechanize in
 one way or another, including
-Kirrily Robert for the orignal C<WWW::Automate>,
+Kirrily Robert for the original C<WWW::Automate>,
+Miyagawa,
 Peteris Krumins,
 Rafael Kitover,
 David Steinbrunner,
@@ -2595,6 +2612,7 @@ Julien Beasley,
 Abe Timmerman,
 Peter Stevens,
 Pete Krawczyk,
+Tad McClellan,
 and the late great Iain Truskett.
 
 =head1 COPYRIGHT
